package com.agilecontrol.nea.core.schema;

import com.agilecontrol.nea.core.control.web.WebUtils;
import com.agilecontrol.nea.core.query.QueryEngine;
import com.agilecontrol.nea.core.query.QueryException;
import com.agilecontrol.nea.core.schema.Client;
import com.agilecontrol.nea.util.NDSRuntimeException;
import com.agilecontrol.nea.util.ObjectNotFoundException;
import com.agilecontrol.nea.util.Tools;
import java.util.Hashtable;
import java.util.List;

public class ClientManager {

   private static ClientManager instance = null;
   private Hashtable clientIds = new Hashtable(3, 0.1F);
   private Hashtable clientDomains = new Hashtable(3, 0.1F);
   private Hashtable clientNames = new Hashtable(3, 0.1F);
   private int defaultClientId = Tools.getInt(WebUtils.getProperty("client.default.clientid"), 37);
   private boolean isSingleClient;


   private ClientManager() {
      try {
         List t = QueryEngine.getInstance().doQueryList("select id,domain,name,description, logourl from ad_client where isactive=\'Y\'", (Object[])null);
         Client client = null;

         for(int i = 0; i < t.size(); ++i) {
            client = new Client((List)t.get(i));
            this.addClient(client);
         }

         if(t.size() == 1) {
            this.defaultClientId = client.getId();
            this.isSingleClient = true;
         }

      } catch (Throwable var4) {
         throw new NDSRuntimeException("Fail to load clients", var4);
      }
   }

   private void addClient(Client client) {
      this.clientIds.put(Integer.valueOf(client.getId()), client);
      this.clientDomains.put(client.getDomain(), client);
      this.clientNames.put(client.getName(), client);
   }

   public boolean isSingleClient() {
      return this.isSingleClient;
   }

   public Client getClient(int id) throws ObjectNotFoundException, QueryException {
      Client client = (Client)this.clientIds.get(Integer.valueOf(id));
      if(client == null) {
         throw new ObjectNotFoundException("client id=" + id + " not found");
      } else {
         return client;
      }
   }

   public Client getClientByDomain(String domain) throws ObjectNotFoundException, QueryException {
      Client client = (Client)this.clientDomains.get(domain);
      if(client == null) {
         throw new ObjectNotFoundException("client domain=" + domain + " not found");
      } else {
         return client;
      }
   }

   public Client getClientByName(String name) throws ObjectNotFoundException, QueryException {
      Client client = (Client)this.clientNames.get(name);
      if(client == null) {
         throw new ObjectNotFoundException("client name=" + name + " not found");
      } else {
         return client;
      }
   }

   public int getDefaultClientId() {
      return this.defaultClientId;
   }

   public Client getDefaultClient() {
      try {
         return this.getClient(this.defaultClientId);
      } catch (Throwable var2) {
         throw new NDSRuntimeException("default client not found");
      }
   }

   public void reload(int id) {
      Client client = (Client)this.clientIds.remove(Integer.valueOf(id));
      if(client != null) {
         this.clientNames.remove(client);
         this.clientDomains.remove(client);
      }

   }

   public static ClientManager getInstance() {
      if(instance == null) {
         instance = new ClientManager();
      }

      return instance;
   }

}
